pub trait PossibleValues:
Sized
+ Clone
+ Eq {
// Required method
fn get_possible_values() -> Vec<(Self, f32)>;
}Expand description
This trait needs to be implemented for all types used in microwfc to allow microwfc to know the superposition. A value can be added multiple times.
Required Methods
fn get_possible_values() -> Vec<(Self, f32)>
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.